@@ -23,11 +23,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 1.1.2
+Version 1.1.3
 
 =cut
 
-our $VERSION = 'v1.1.2';
+our $VERSION = 'v1.1.3';
 
 =head1 SYNOPSIS
 
@@ -566,7 +566,7 @@ sub retrieve_latest_artifact {
     my $basename = basename($path);
     my $url;
     $url = "$base_url/$version-SNAPSHOT/$basename-$version-SNAPSHOT.jar" if ( $version && $flag eq 'snapshot' );
-    $url = "$base_url/$release/$basename-$release.jar"                   if ( $flag eq 'release' );
+    $url = "$base_url/$release/$basename-$release.jar"                   if ( $flag             eq 'release' );
     $url = "$base_url/$version-$integration/$basename-$version-$integration.jar"
       if ( $version && $flag eq 'integration' );
     return $self->get($url);
@@ -923,6 +923,43 @@ sub enable_or_disable_multiple_replications {
     );
 }
 
+=head2 get_system_replication_status
+
+Returns the global system replication status (blocked or unblocked).
+
+=cut
+
+sub get_system_replication_status {
+    my $self = shift;
+    my $repo = $self->repository();
+    my $url  = $self->_api_url() . "/system/replications";
+    return $self->get($url);
+}
+
+=head2 block_system_replication( push => 'false', pull => 'true' )
+
+Blocks replications globally. Push and pull are true by default. If false, replication for the corresponding type is not
+blocked.
+
+=cut
+
+sub block_system_replication {
+    my ( $self, %args ) = @_;
+    return $self->_handle_block_system_replication( 'block', %args );
+}
+
+=head2 unblock_system_replication( push => 'false', pull => 'true' )
+
+Unblocks replications globally. Push and pull are true by default. If false, replication for the corresponding type is
+not unblocked.
+
+=cut
+
+sub unblock_system_replication {
+    my ( $self, %args ) = @_;
+    return $self->_handle_block_system_replication( 'unblock', %args );
+}
+
 =head2 artifact_sync_download( $path, content => 'progress', mark => 1000 )
 
 Downloads an artifact with or without returning the actual content to the client. When tracking the progress marks are
@@ -2598,6 +2635,18 @@ sub _handle_revoke_api_key {
     return $self->delete( $url, %header );
 }
 
+sub _handle_block_system_replication {
+    my ( $self, $ep, %args ) = @_;
+    my %merged = (
+        push => 'true',
+        pull => 'true',
+        %args              # overriding defaults
+    );
+    my $repo = $self->repository();
+    my $url = $self->_api_url() . "/system/replications/$ep?" . $self->_stringify_hash( '&', %merged );
+    return $self->post($url);
+}
+
 __PACKAGE__->meta->make_immutable;
 
 =head1 AUTHOR
